@@ -4,6 +4,8 @@ import urllib.request
 import urllib.parse
 from threading import Lock
 import logging
+import sys
+import os.path
 
 from .conf import settings
 from datetime import datetime
@@ -252,3 +254,17 @@ def none_fallback(value, fallback):
     if value is None:
         return fallback
     return value
+
+def get_resource(*path):
+    # Detect if bundled via pyinstaller.
+    # From: https://stackoverflow.com/questions/404744/
+    if getattr(sys, '_MEIPASS', False):
+        application_path = os.path.join(sys._MEIPASS, "jellyfin_mpv_shim")
+    else:
+        application_path = os.path.dirname(os.path.abspath(__file__))
+
+    return os.path.join(application_path, *path)
+
+def get_text(*path):
+    with open(get_resource(*path)) as fh:
+        return fh.read()
